==> jc-1.4.0.tar.gz: soot/jimple/JasminClass__246.h <==
// class soot.jimple.JasminClass$6

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 284aff14bea3930f soot_jimple_AbstractJimpleValueSwitch
// @dep_class f02d3e1ddc813f47 soot_jimple_JasminClass__246

// header file dependencies
// @dep_header soot_jimple_AbstractJimpleValueSwitch

#include "soot/jimple/AbstractJimpleValueSwitch.h"

#ifndef _JC_soot_jimple_JasminClass__246_H_
#define _JC_soot_jimple_JasminClass__246_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_EqExpr$object;
struct _jc_soot_jimple_GeExpr$object;
struct _jc_soot_jimple_GtExpr$object;
struct _jc_soot_jimple_JasminClass$object;
struct _jc_soot_jimple_LeExpr$object;
struct _jc_soot_jimple_LtExpr$object;
struct _jc_soot_jimple_NeExpr$object;

// Typedefs
typedef struct _jc_soot_jimple_JasminClass__246$sub_refs	_jc_soot_jimple_JasminClass__246$sub_refs;
typedef struct _jc_soot_jimple_JasminClass__246$sub_nonrefs	_jc_soot_jimple_JasminClass__246$sub_nonrefs;
typedef struct _jc_soot_jimple_JasminClass__246$refs	_jc_soot_jimple_JasminClass__246$refs;
typedef struct _jc_soot_jimple_JasminClass__246$nonrefs	_jc_soot_jimple_JasminClass__246$nonrefs;
typedef struct _jc_soot_jimple_JasminClass__246$object	_jc_soot_jimple_JasminClass__246$object;

typedef const struct _jc_soot_jimple_JasminClass__246$vmethods	_jc_soot_jimple_JasminClass__246$vmethods;
typedef const struct _jc_soot_jimple_JasminClass__246$vtable	_jc_soot_jimple_JasminClass__246$vtable;
typedef const struct _jc_soot_jimple_JasminClass__246$vtype	_jc_soot_jimple_JasminClass__246$vtype;

// Constructors
extern void _jc_soot_jimple_JasminClass__246$method$_init$8ffd1941f8027b3f(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_soot_jimple_JasminClass$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_soot_jimple_JasminClass__246$method$caseEqExpr$257a90483e67b655(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *);
extern void _jc_soot_jimple_JasminClass__246$method$caseGeExpr$aeefb596890e26e8(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *);
extern void _jc_soot_jimple_JasminClass__246$method$caseGtExpr$cb797c3eb6a9f75e(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *);
extern void _jc_soot_jimple_JasminClass__246$method$caseLeExpr$4c8194d61e4953f4(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *);
extern void _jc_soot_jimple_JasminClass__246$method$caseLtExpr$8fedb86ba4f14443(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *);
extern void _jc_soot_jimple_JasminClass__246$method$caseNeExpr$548eb7155be241b9(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *);
extern void _jc_soot_jimple_JasminClass__246$method$defaultCase$707752a9a764fffd(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_JasminClass__246$method_info$caseEqExpr$257a90483e67b655;
extern _jc_method _jc_soot_jimple_JasminClass__246$method_info$caseGeExpr$aeefb596890e26e8;
extern _jc_method _jc_soot_jimple_JasminClass__246$method_info$caseGtExpr$cb797c3eb6a9f75e;
extern _jc_method _jc_soot_jimple_JasminClass__246$method_info$caseLeExpr$4c8194d61e4953f4;
extern _jc_method _jc_soot_jimple_JasminClass__246$method_info$caseLtExpr$8fedb86ba4f14443;
extern _jc_method _jc_soot_jimple_JasminClass__246$method_info$caseNeExpr$548eb7155be241b9;
extern _jc_method _jc_soot_jimple_JasminClass__246$method_info$defaultCase$707752a9a764fffd;

// Virtual methods structure
struct _jc_soot_jimple_JasminClass__246$vmethods {
	void	(*caseEqExpr$257a90483e67b655)(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *);
	void	(*caseGeExpr$aeefb596890e26e8)(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *);
	void	(*caseGtExpr$cb797c3eb6a9f75e)(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *);
	void	(*caseLeExpr$4c8194d61e4953f4)(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *);
	void	(*caseLtExpr$8fedb86ba4f14443)(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *);
	void	(*caseNeExpr$548eb7155be241b9)(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *);
	void	(*defaultCase$707752a9a764fffd)(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_JasminClass__246$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractJimpleValueSwitch$vmethods	soot_jimple_AbstractJimpleValueSwitch;
	_jc_soot_jimple_JasminClass__246$vmethods	soot_jimple_JasminClass__246;
};

// Vtype
struct _jc_soot_jimple_JasminClass__246$vtype {
	_jc_type			type;
	_jc_soot_jimple_JasminClass__246$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_JasminClass__246$sub_refs {
	struct _jc_java_lang_String$object	*val__24label;
	struct _jc_soot_jimple_JasminClass$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_JasminClass__246$refs {
    _jc_soot_jimple_JasminClass__246$sub_refs	soot_jimple_JasminClass__246;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_refs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_JasminClass__246$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_JasminClass__246$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_nonrefs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_soot_jimple_JasminClass__246$sub_nonrefs	soot_jimple_JasminClass__246;
};

// Object instance structure
struct _jc_soot_jimple_JasminClass__246$object {
	_jc_soot_jimple_JasminClass__246$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_JasminClass__246$vtype	*vtype;
	_jc_soot_jimple_JasminClass__246$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_JasminClass__246$vtype _jc_soot_jimple_JasminClass__246$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_JasminClass__246, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_JasminClass__246$class_object;

#endif	/* _JC_soot_jimple_JasminClass__246_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/JasminClass__246.h <==
// class soot.jimple.JasminClass$6

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 284aff14bea3930f soot_jimple_AbstractJimpleValueSwitch
// @dep_class f02d3e1ddc813f47 soot_jimple_JasminClass__246

// header file dependencies
// @dep_header soot_jimple_AbstractJimpleValueSwitch

#include "soot/jimple/AbstractJimpleValueSwitch.h"

#ifndef _JC_soot_jimple_JasminClass__246_H_
#define _JC_soot_jimple_JasminClass__246_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_EqExpr$object;
struct _jc_soot_jimple_GeExpr$object;
struct _jc_soot_jimple_GtExpr$object;
struct _jc_soot_jimple_JasminClass$object;
struct _jc_soot_jimple_LeExpr$object;
struct _jc_soot_jimple_LtExpr$object;
struct _jc_soot_jimple_NeExpr$object;

// Typedefs
typedef struct _jc_soot_jimple_JasminClass__246$sub_refs	_jc_soot_jimple_JasminClass__246$sub_refs;
typedef struct _jc_soot_jimple_JasminClass__246$sub_nonrefs	_jc_soot_jimple_JasminClass__246$sub_nonrefs;
typedef struct _jc_soot_jimple_JasminClass__246$refs	_jc_soot_jimple_JasminClass__246$refs;
typedef struct _jc_soot_jimple_JasminClass__246$nonrefs	_jc_soot_jimple_JasminClass__246$nonrefs;
typedef struct _jc_soot_jimple_JasminClass__246$object	_jc_soot_jimple_JasminClass__246$object;

typedef const struct _jc_soot_jimple_JasminClass__246$vmethods	_jc_soot_jimple_JasminClass__246$vmethods;
typedef const struct _jc_soot_jimple_JasminClass__246$vtable	_jc_soot_jimple_JasminClass__246$vtable;
typedef const struct _jc_soot_jimple_JasminClass__246$vtype	_jc_soot_jimple_JasminClass__246$vtype;

// Constructors
extern void _jc_soot_jimple_JasminClass__246$method$_init$8ffd1941f8027b3f(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_soot_jimple_JasminClass$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_JasminClass__246$method$caseEqExpr$257a90483e67b655(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_JasminClass__246$method$caseGeExpr$aeefb596890e26e8(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_JasminClass__246$method$caseGtExpr$cb797c3eb6a9f75e(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_JasminClass__246$method$caseLeExpr$4c8194d61e4953f4(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_JasminClass__246$method$caseLtExpr$8fedb86ba4f14443(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_JasminClass__246$method$caseNeExpr$548eb7155be241b9(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_JasminClass__246$method$defaultCase$707752a9a764fffd(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_JasminClass__246$method_info$caseEqExpr$257a90483e67b655;
extern _jc_method _jc_soot_jimple_JasminClass__246$method_info$caseGeExpr$aeefb596890e26e8;
extern _jc_method _jc_soot_jimple_JasminClass__246$method_info$caseGtExpr$cb797c3eb6a9f75e;
extern _jc_method _jc_soot_jimple_JasminClass__246$method_info$caseLeExpr$4c8194d61e4953f4;
extern _jc_method _jc_soot_jimple_JasminClass__246$method_info$caseLtExpr$8fedb86ba4f14443;
extern _jc_method _jc_soot_jimple_JasminClass__246$method_info$caseNeExpr$548eb7155be241b9;
extern _jc_method _jc_soot_jimple_JasminClass__246$method_info$defaultCase$707752a9a764fffd;

// Virtual methods structure
struct _jc_soot_jimple_JasminClass__246$vmethods {
	void	(*caseEqExpr$257a90483e67b655)(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseGeExpr$aeefb596890e26e8)(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseGtExpr$cb797c3eb6a9f75e)(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseLeExpr$4c8194d61e4953f4)(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseLtExpr$8fedb86ba4f14443)(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*caseNeExpr$548eb7155be241b9)(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*defaultCase$707752a9a764fffd)(_jc_env *, struct _jc_soot_jimple_JasminClass__246$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_JasminClass__246$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractJimpleValueSwitch$vmethods	soot_jimple_AbstractJimpleValueSwitch;
	_jc_soot_jimple_JasminClass__246$vmethods	soot_jimple_JasminClass__246;
};

// Vtype
struct _jc_soot_jimple_JasminClass__246$vtype {
	_jc_type			type;
	_jc_soot_jimple_JasminClass__246$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_JasminClass__246$sub_refs {
	struct _jc_java_lang_String$object	*val__24label;
	struct _jc_soot_jimple_JasminClass$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_JasminClass__246$refs {
    _jc_soot_jimple_JasminClass__246$sub_refs	soot_jimple_JasminClass__246;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_refs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_JasminClass__246$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_JasminClass__246$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_nonrefs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_soot_jimple_JasminClass__246$sub_nonrefs	soot_jimple_JasminClass__246;
};

// Object instance structure
struct _jc_soot_jimple_JasminClass__246$object {
	_jc_soot_jimple_JasminClass__246$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_JasminClass__246$vtype	*vtype;
	_jc_soot_jimple_JasminClass__246$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_JasminClass__246$vtype _jc_soot_jimple_JasminClass__246$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_JasminClass__246, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_JasminClass__246$class_object;

#endif	/* _JC_soot_jimple_JasminClass__246_H_ */
